/*
	streamGauge.js
	for Stream Gauge Widget
	by Jerry Brown.
	
	This widget grabs the latest text feed from the USGS using gauge station numbers the user defines, shows the station name and flow or height, depending on user preference, and updates the data every 30 minutes. 

	Version 1.4

	(c) 2004 Jerry Brown
*/
	
	    var dataArray = new Array(9);
	    var munit;
	    var gaugeArray = new Array();
	    var gaugeNum = new Array();


	    function getDischarge() {

		var stationList = new Array();
		var itemHeight = 26;
			
		if (preferences.userStationsPref.value == "") {
		    pref = preferences.userStationPref.defaultValue
		    }
		else {
		    pref = preferences.userStationsPref.value + ","
		    }
		stationSplit = /([0-9]*)[ ,;:]*/g;
		theSplit = pref.match(stationSplit);

		for ( item in theSplit ) {
		    stationClean = /([0-9]*)[ ,;:]*/;
		    tempStationList = theSplit[item].match(stationClean);
		    stationList[item] = tempStationList[1];
		    }
		stationList = stationList.slice(0,-1);
		stationList.sort(function(a,b) {
		    return a-b;
		    });
		cleanPref = "";
		for ( item in stationList ) {
		    cleanPref = cleanPref + stationList[item] + ", ";
		    }
		preferences.userStationsPref.value = cleanPref.substr(0, (cleanPref.length - 2));
			
		//Build URL to fetch station discharge
		theURL = "http://waterdata.usgs.gov/nwis/current?multiple_site_no=";

		for (item in stationList) {
		    theURL = theURL + stationList[item] + "%0D%0A";
		    }

		//Check to see what we the measurement is in prefs    
		switch (preferences.gaugeDataPref.value) {
		    case "Height (ft)":
		        mcode = "00065";
			break;
		    case "Flow (ft3/sec)":
		        mcode = "00060";
		        break;
		    }

		//Set the appropriate measurement unit
		switch (mcode) {
		    case "00065":
		        munit = "ft";
		        break;
		    case "00060":
		        munit = "ft\u00B3/s";
		        break;
		    }

		theURL = theURL + "&search_site_no_match_type=exact&index_pmcode_STATION_NM=1&index_pmcode_" + mcode + "=2&sort_key=site_no&group_key=NONE&sitefile_output_format=rdb&column_name=site_no&column_name=station_nm&column_name=alt_va&column_name=huc_cd&html_table_sort_key=site_no&html_table_group_key=basin_cd&pre_format=on&format=rdb&rdb_compression=&list_of_search_criteria=multiple_site_no%2Crealtime_parameter_selection";
		
		var urldata;
		//Fetch the URL
		var url = new URL();
		urldata = url.fetch(theURL);

		//Remove a bunch of crap from the text that is returned
		a = /#(.*)\n/g;
		urldata = urldata.replace(a, "");
		b = /^agency(.*)\n/g;
		urldata = urldata.replace(b, "");
		c = /^5s(.*)\n/g;
		urldata = urldata.replace(c, "");
		
		//Create an array of each row of data
		gaugeArray = urldata.split("\n");
		gaugeArray = gaugeArray.slice(0,-1);
		
		//Create an array of data in each row
		for(var i = 0; i < (gaugeArray.length); i++)
		dataArray[i] = gaugeArray[i].split("\t");
		
		//Print it out!
		for(var i = 0; i < (gaugeArray.length); i++)
		print(dataArray[i][1] + "\t" + dataArray[i][2] + "\t " + dataArray [i][6]);
		drawWindow();
	    }


	    function formatText(gaugeText) {
	    
	    	txt = gaugeText;
	    	newTxt = "";

		//Convert all text to lower case, then capitalize the first
		//letter in each word
		txt = txt.toLowerCase();
		txt = txt.split(" ");
	    	for(n = 0; n < txt.length; n++) {
	    		newTxt += txt[n].substring(0,1).toUpperCase() + txt[n].substring(1,txt[n].length) + " ";
	    	}
		gaugeText = newTxt;
		return gaugeText;
	    }
	        

	    function browseGauge(gaugeNumber) {	
	        var url = "http://waterdata.usgs.gov/nwis/uv/?site_no=" + gaugeNumber + "&PARAmeter_cd=00065,00060";
	        openURL(url);		
	    }


	    function drawWindow() {

		var itemHeight = 26;
		gaugeBackground = new Array();
		gaugeNameShadow = new Array();
		gaugeName = new Array();
		gaugeDischargeShadow = new Array();
		gaugeDischarge = new Array();

		main_window.height = (itemHeight * gaugeArray.length);

		for(i in gaugeArray) {
				
		    vertOffset = i * itemHeight;

		    var gaugeData = gaugeArray[i];

		    gaugeNum[gaugeData] = new Text();
		    gaugeNum[gaugeArray[i]].data = dataArray[i][1];
		    
		    gaugeBackground[gaugeData] = new Image();
		    gaugeBackground[gaugeData].src = "Resources/background.png";
		    gaugeBackground[gaugeData].vOffset = itemHeight * i;
		    gaugeBackground[gaugeData].hOffset = background.hOffset;
		    gaugeBackground[gaugeData].opacity = preferences.backgroundOpacityPref.value;

		    gaugeNameShadow[gaugeData] = new Text();
		    gaugeNameShadow[gaugeData].data = dataArray[i][2];
		    gaugeText = gaugeNameShadow[gaugeData].data;
		    gaugeNameShadow[gaugeData].data = formatText(gaugeText);
		    gaugeNameShadow[gaugeData].vOffset = (itemHeight * i) + 16;
		    gaugeNameShadow[gaugeData].hOffset = nameShadow.hOffset;
		    gaugeNameShadow[gaugeData].font = nameShadow.font;
		    gaugeNameShadow[gaugeData].size = nameShadow.size;
		    gaugeNameShadow[gaugeData].style = nameShadow.style;
		    gaugeNameShadow[gaugeData].color = nameShadow.color;
		    gaugeNameShadow[gaugeData].opacity = 170;

		    gaugeName[gaugeData] = new Text();
		    gaugeName[gaugeData].data = gaugeNameShadow[gaugeData].data;
		    print(gaugeName[gaugeData].data);
		    gaugeName[gaugeData].onMouseUp = "browseGauge(gaugeNum[gaugeArray[i]].data);";
		    gaugeName[gaugeData].vOffset = (itemHeight * i) + 15;
		    gaugeName[gaugeData].hOffset = name.hOffset;
		    gaugeName[gaugeData].font = name.font;
		    gaugeName[gaugeData].size = name.size;
		    gaugeName[gaugeData].style = name.style;
		    switch(preferences.textColorPref.value) {
			case "Red":
			    gaugeName[gaugeData].color = "#ff0000";
			    break;		
			case "Black":
			    gaugeName[gaugeData].color = "#000000";
			    break;
			case "Green":
			    gaugeName[gaugeData].color = "#006600";
			    break;
			case "Blue":
			    gaugeName[gaugeData].color = "#0000cc";
			    break;
			case "Orange":
			    gaugeName[gaugeData].color = "#ff6600";
			    break;
			case "Gray":
			    gaugeName[gaugeData].color = "#333333";
			    break;
			case "White":
			    gaugeName[gaugeData].color = "#ffffff";
			    break;
		    }


		    gaugeDischargeShadow[gaugeData] = new Text();
		    gaugeDischargeShadow[gaugeData].data = dataArray[i][6] + " " + munit;
		    gaugeDischargeShadow[gaugeData].vOffset = (itemHeight * i) + 16;
		    gaugeDischargeShadow[gaugeData].hOffset = flowShadow.hOffset;
		    gaugeDischargeShadow[gaugeData].font = flowShadow.font;
		    gaugeDischargeShadow[gaugeData].size = flowShadow.size;
		    gaugeDischargeShadow[gaugeData].style = flowShadow.style;
		    gaugeDischargeShadow[gaugeData].color = flowShadow.color;
		    gaugeDischargeShadow[gaugeData].opacity = 170;

		    gaugeDischarge[gaugeData] = new Text();
		    gaugeDischarge[gaugeData].data = dataArray[i][6] + " " + munit;
		    gaugeDischarge[gaugeData].vOffset = (itemHeight * i) + 15;
		    gaugeDischarge[gaugeData].hOffset = flow.hOffset;
		    gaugeDischarge[gaugeData].font = flow.font;
		    gaugeDischarge[gaugeData].size = flow.size;
		    gaugeDischarge[gaugeData].style = flow.style;
		    switch(preferences.textColorPref.value) {
			case "Red":
		 	    gaugeDischarge[gaugeData].color = "#ff0000";
			    break;
			case "Black":
			    gaugeDischarge[gaugeData].color = "#000000";
			    break;
			case "Green":
			    gaugeDischarge[gaugeData].color = "#006600";
			    break;
			case "Blue":
			    gaugeDischarge[gaugeData].color = "#0000cc";
			    break;
			case "Orange":
			    gaugeDischarge[gaugeData].color = "#ff6600";
			    break;
			case "Gray":
			    gaugeDischarge[gaugeData].color = "#333333";
			    break;
			case "White":
			    gaugeDischarge[gaugeData].color = "#ffffff";
			    break;
		    }
		}
	    }

	    getDischarge();
	    main_window.visible = true;
